AnimationEvaluationError

Enum AnimationEvaluationError 

pub enum AnimationEvaluationError {
    ComponentNotPresent(TypeId),
    PropertyNotPresent(TypeId),
    InconsistentEvaluatorImplementation(TypeId),
}
Why Bevy failed to evaluate an animation.

Variants



ComponentNotPresent(TypeId)

The component to be animated isn’t present on the animation target.

To fix this error, make sure the entity to be animated contains all components that have animation curves.



PropertyNotPresent(TypeId)

The component to be animated was present, but the property on the component wasn’t present.



InconsistentEvaluatorImplementation(TypeId)

An internal error occurred in the implementation of AnimationCurveEvaluator.

You shouldn’t ordinarily see this error unless you implemented AnimationCurveEvaluator yourself. The contained TypeId is the ID of the curve evaluator.