pub struct SerializedAnimationGraph {
pub graph: DiGraph<SerializedAnimationGraphNode, (), u32>,
pub root: NodeIndex,
pub mask_groups: HashMap<AnimationTargetId, AnimationMask>,
}Expand description
A version of AnimationGraph suitable for serializing as an asset.
Animation nodes can refer to external animation clips, and the AssetId
is typically not sufficient to identify the clips, since the
bevy_asset::AssetServer assigns IDs in unpredictable ways. That fact
motivates this type, which replaces the Handle<AnimationClip> with an
asset path. Loading an animation graph via the bevy_asset::AssetServer
actually loads a serialized instance of this type, as does serializing an
AnimationGraph through serde.
Fields
graph: DiGraph<SerializedAnimationGraphNode, (), u32>Corresponds to the graph field on AnimationGraph.
root: NodeIndexCorresponds to the root field on AnimationGraph.
mask_groups: HashMap<AnimationTargetId, AnimationMask>Corresponds to the mask_groups field on AnimationGraph.